@@ -37,7 +37,7 @@ class ExtraData:
         for extra in self:
             try:
                 res[extra.name()] = extra.as_dict()
-            except StructError as e:
+            except (StructError, ValueError) as e:
                 msg = "Error while parsing `%s` (%s)" % (extra.name(), e)
                 warnings.warn(msg)
                 continue
